========
qt-epics
========

.. image:: https://img.shields.io/travis/JunAishima/qt-epics.svg
        :target: https://travis-ci.org/JunAishima/qt-epics

.. image:: https://img.shields.io/pypi/v/qt-epics.svg
        :target: https://pypi.python.org/pypi/qt-epics


Qt-based widgets for PyEpics devices

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://JunAishima.github.io/qt-epics.

Features
--------

* TODO
